@@ -16,7 +16,7 @@ def get_req_list(
     list_of_deps = list(dependency_graph.graph.keys())
     if len(list_of_deps) == 1:
         return list_of_deps
-    elif requirements_list is not None:
+    elif requirements_list is not None and requirements_list != []:
         return requirements_list
     else:
         return lib.get_requirement_list(dependency_graph.module_list())
